# AntU
Universal data IO and neural network modules in NLP tasks.

+ **data IO** is an universal module in Natural Language Processing system and not based on any framework (like TensorFlow, PyTorch, MXNet, Dynet...).
+ **neural network** module contains the neural network structures commonly used in NLP tasks. We want to design commonly used structures for each neural network framework. We will continue to develop this module.



# Requirements

+ Python>=3.6
+ bidict==0.17.5
+ numpy==1.15.4
+ numpydoc==0.8.0
+ overrides==1.9
+ pytest==4.0.2

##### If you need dynet neural network:

+ dynet>=2.0



# Installing via pip

```bash
pip install antu
```



# Resources

+ [Documentation](https://antu.readthedocs.io/en/latest/index.html)
+ [Source Code](https://github.com/AntNLP/antu)

